@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2015 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -142,8 +141,8 @@ class FileSharing(Serialisable):
     userName = String(allow_none=True)
     reservationPassword = HexBinary(allow_none=True)
     algorithmName = String(allow_none=True)
-    hashValue = HexBinary(allow_none=True)
-    saltValue = HexBinary(allow_none=True)
+    hashValue = Base64Binary(allow_none=True)
+    saltValue = Base64Binary(allow_none=True)
     spinCount = Integer(allow_none=True)
 
     def __init__(self,
